==> tutti-ui-swing-1.0-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/fishing/hydrology/HydrologyRowModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.fishing.hydrology;

/*
 * #%L
 * Tutti :: UI
 * $Id: HydrologyRowModel.java 268 2013-01-30 12:38:14Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/fishing/hydrology/HydrologyRowModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.content.operation.fishing.CaracteristicRowModel;

/**
 * @author kmorin
 * @since 0.3
 */
public class HydrologyRowModel extends CaracteristicRowModel<HydrologyRowModel> {

    private static final long serialVersionUID = 1L;
//
//    public static final String PROPERTY_GEAR_SHOOTING_START_VALUE = "gearShootingStartValue";
//
//    public static final String PROPERTY_GEAR_SHOOTING_END_VALUE = "gearShootingEndValue";
//
//    public static final String PROPERTY_AVERAGE_VALUE = "averageValue";
//
//    protected Serializable gearShootingStartValue;
//
//    protected Serializable gearShootingEndValue;
//
//    protected Serializable averageValue;

//    public HydrologyRowModel() {
//        super();
//    }
//
//    public HydrologyRowModel(Caracteristic key) {
//        this(key, null, null, null);
//    }
//
//    public HydrologyRowModel(Caracteristic key, Serializable gearShootingStartValue,
//                             Serializable gearShootingEndValue, Serializable averageValue) {
//        this();
//        this.key = key;
//        this.gearShootingStartValue = gearShootingStartValue;
//        this.gearShootingEndValue = gearShootingEndValue;
//        this.averageValue = averageValue;
//    }
//
//    public Serializable getGearShootingStartValue() {
//        return gearShootingStartValue;
//    }
//
//    public void setGearShootingStartValue(Serializable gearShootingStartValue) {
//        Object oldValue = getGearShootingStartValue();
//        this.gearShootingStartValue = gearShootingStartValue;
//        firePropertyChange(PROPERTY_GEAR_SHOOTING_START_VALUE, oldValue, gearShootingStartValue);
//    }
//
//    public Serializable getGearShootingEndValue() {
//        return gearShootingEndValue;
//    }
//
//    public void setGearShootingEndValue(Serializable gearShootingEndValue) {
//        Object oldValue = getGearShootingEndValue();
//        this.gearShootingEndValue = gearShootingEndValue;
//        firePropertyChange(PROPERTY_GEAR_SHOOTING_END_VALUE, oldValue, gearShootingEndValue);
//    }
//
//    public Serializable getAverageValue() {
//        return averageValue;
//    }
//
//    public void setAverageValue(Serializable averageValue) {
//        Object oldValue = getAverageValue();
//        this.averageValue = averageValue;
//        firePropertyChange(PROPERTY_AVERAGE_VALUE, oldValue, averageValue);
//    }

}

==> tutti-ui-swing-1.0.1-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/fishing/hydrology/HydrologyRowModel.java <==
package fr.ifremer.tutti.ui.swing.content.operation.fishing.hydrology;

/*
 * #%L
 * Tutti :: UI
 * $Id: HydrologyRowModel.java 268 2013-01-30 12:38:14Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/fishing/hydrology/HydrologyRowModel.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.content.operation.fishing.CaracteristicRowModel;

/**
 * @author kmorin
 * @since 0.3
 */
public class HydrologyRowModel extends CaracteristicRowModel<HydrologyRowModel> {

    private static final long serialVersionUID = 1L;
//
//    public static final String PROPERTY_GEAR_SHOOTING_START_VALUE = "gearShootingStartValue";
//
//    public static final String PROPERTY_GEAR_SHOOTING_END_VALUE = "gearShootingEndValue";
//
//    public static final String PROPERTY_AVERAGE_VALUE = "averageValue";
//
//    protected Serializable gearShootingStartValue;
//
//    protected Serializable gearShootingEndValue;
//
//    protected Serializable averageValue;

//    public HydrologyRowModel() {
//        super();
//    }
//
//    public HydrologyRowModel(Caracteristic key) {
//        this(key, null, null, null);
//    }
//
//    public HydrologyRowModel(Caracteristic key, Serializable gearShootingStartValue,
//                             Serializable gearShootingEndValue, Serializable averageValue) {
//        this();
//        this.key = key;
//        this.gearShootingStartValue = gearShootingStartValue;
//        this.gearShootingEndValue = gearShootingEndValue;
//        this.averageValue = averageValue;
//    }
//
//    public Serializable getGearShootingStartValue() {
//        return gearShootingStartValue;
//    }
//
//    public void setGearShootingStartValue(Serializable gearShootingStartValue) {
//        Object oldValue = getGearShootingStartValue();
//        this.gearShootingStartValue = gearShootingStartValue;
//        firePropertyChange(PROPERTY_GEAR_SHOOTING_START_VALUE, oldValue, gearShootingStartValue);
//    }
//
//    public Serializable getGearShootingEndValue() {
//        return gearShootingEndValue;
//    }
//
//    public void setGearShootingEndValue(Serializable gearShootingEndValue) {
//        Object oldValue = getGearShootingEndValue();
//        this.gearShootingEndValue = gearShootingEndValue;
//        firePropertyChange(PROPERTY_GEAR_SHOOTING_END_VALUE, oldValue, gearShootingEndValue);
//    }
//
//    public Serializable getAverageValue() {
//        return averageValue;
//    }
//
//    public void setAverageValue(Serializable averageValue) {
//        Object oldValue = getAverageValue();
//        this.averageValue = averageValue;
//        firePropertyChange(PROPERTY_AVERAGE_VALUE, oldValue, averageValue);
//    }

}
